Layout
======

command : linchpin layout 

This command lists all the layouts available and copies layouts to the layouts folder in current working directory.


Options :
  get       get layout based on name 
  list      list all the existing topologies


=========
Examples:
=========

+----------------------+----------------------------------------------------+
| Usage                | Action                                             |
+----------------------+----------------------------------------------------+
| linchpin layout list | Lists all the layouts packaged in linchpin         |
+----------------------+----------------------------------------------------+
+ linchpin layout get  + Copies the layout file from the package by name    +
| <layoutname>         | into layouts folder of current working directory.  |
+----------------------+----------------------------------------------------+
